==> koffice-trinity_3.5.13.2.orig.tar.xz: koffice-trinity-3.5.13.2/karbon/tools/vrectangletool.h <==
/* This file is part of the KDE project
   Copyright (C) 2001, 2002, 2003 The Karbon Developers

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef __VRECTANGLETOOL_H__
#define __VRECTANGLETOOL_H__


#include <klocale.h>
#include <kdialogbase.h>

#include "vshapetool.h"

class KarbonView;
class TQLabel;
class KoUnitDoubleSpinBox;

class VRectangleTool : public VShapeTool
{
public:
	VRectangleTool( KarbonView *view );
	virtual ~VRectangleTool();

	virtual void setup(KActionCollection *collection);
	virtual bool showDialog() const;
	virtual TQString uiname() { return i18n( "Rectangle Tool" ); }
	virtual VPath* shape( bool interactive = false ) const;

	void refreshUnit();

private:
	class VRectangleOptionsWidget : public KDialogBase
	{
	public:
		VRectangleOptionsWidget( KarbonPart *part, TQWidget* parent = 0L, const char* name = 0L );

		double width() const;
		double height() const;
		void setWidth( double value );
		void setHeight( double value );
		void refreshUnit();

	private:
		KoUnitDoubleSpinBox		*m_width;
		KoUnitDoubleSpinBox		*m_height;
		KarbonPart 			*m_part;
		TQLabel				*m_heightLabel;
		TQLabel				*m_widthLabel;
	};

	VRectangleOptionsWidget *m_optionWidget;
};

#endif

==> koffice-trinity_14.1.5.orig.tar.xz: koffice-trinity-14.1.5/karbon/tools/vrectangletool.h <==
/* This file is part of the KDE project
   Copyright (C) 2001, 2002, 2003 The Karbon Developers

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef __VRECTANGLETOOL_H__
#define __VRECTANGLETOOL_H__


#include <tdelocale.h>
#include <kdialogbase.h>

#include "vshapetool.h"

class KarbonView;
class TQLabel;
class KoUnitDoubleSpinBox;

class VRectangleTool : public VShapeTool
{
public:
	VRectangleTool( KarbonView *view );
	virtual ~VRectangleTool();

	virtual void setup(TDEActionCollection *collection);
	virtual bool showDialog() const;
	virtual TQString uiname() { return i18n( "Rectangle Tool" ); }
	virtual VPath* shape( bool interactive = false ) const;

	void refreshUnit();

private:
	class VRectangleOptionsWidget : public KDialogBase
	{
	public:
		VRectangleOptionsWidget( KarbonPart *part, TQWidget* parent = 0L, const char* name = 0L );

		double width() const;
		double height() const;
		void setWidth( double value );
		void setHeight( double value );
		void refreshUnit();

	private:
		KoUnitDoubleSpinBox		*m_width;
		KoUnitDoubleSpinBox		*m_height;
		KarbonPart 			*m_part;
		TQLabel				*m_heightLabel;
		TQLabel				*m_widthLabel;
	};

	VRectangleOptionsWidget *m_optionWidget;
};

#endif
